plotECDF.FCS <- function(data,
                         varpos,
                         var.list, 
                         group.list,
                         xlab,
                         ylab,
                          ...                        
                        ){

    ## Create a empirical cumulative distribution plot
    ## Nolwenn Le Meur
    ## 18 Sept 2005. Last revised 05 Dec 2005
    
    ## x            data from an cytoSet object
    ## varpos       the variable column position of the data being examined
    ##              or a vector of column postions
    ## var.list     conditioning variables
    ## group.list   a variable or expression to be evaluated in the data frame
    ##              specified by 'data', expected to act as a grouping variable
    ##              within each panel, typically used to distinguish different
    ##              groups by varying graphical parameters like color and line
    ##              type.
    
    ##example:
    ##  plotECDF.FCS(fluors.data[1:72],varpos=c(1),var.list=c("leukocytes","Tcells","NKcells","Bcells","TCR","1Act","2Act","3Act"),group.list=c(paste("time",1:9,sep="")),main="test")
    ##  plotECDF.FCS(fluors.data[1:72],varpos=c(1),group.list=c("leukocytes","Tcells","NKcells","Bcells","TCR","1Act","2Act","3Act"),var.list=c(paste("time",1:9,sep="")),main="test")

  
    if (!require(lattice, quietly = TRUE)) {
        stop("The lattice library is required for this function.\n")
    }
    if((!is(data, "cytoSet")) && (!is(data[[1]],"FCS"))){
        stop("input 'object' must be a cytoSet object or a list of FCS objects")
    }
        
    
    nbdata <-length(data)
    nbvar <- length(var.list)
    nbgroup <- length(group.list)
                                        #test
    if(nbvar*nbgroup!=nbdata) stop("The number of FCS objets to plot is different from the number of conditioning variables by the number of grouping variables (x different from var.list x group.list).")
       
    if (missing(xlab)) xlab <- "Intensity"
    if (missing(ylab)) ylab <- "Empirical cumulative distribution"
    
    
    res.ecdf <-list()
    res <- list()
    y.ecdf <- x.ecdf <- NULL
    group <- NULL
    group.size <- NULL
     x <-vector("list")
    
    ##extract values
    if(is(data,"cytoSet")){
        for (i in 1:length(data)){
            x[[i]]<-exprs(data[[i]])
        }
    }
      
    if(is(data[[1]],"FCS")){
        if (is.list(data)){
            x<-lapply(data,fluors)
        }
    }
    
    res.length <- lapply(x,function(x){length(x[,varpos])})
    res.ecdf <- lapply(x,function(x){ecdf(x[,varpos])})
    
    
    for(i in 1:length(x)){
        y.ecdf <- c(y.ecdf, environment(res.ecdf[[i]])$y)
        x.ecdf <- c(x.ecdf, environment(res.ecdf[[i]])$x)
        group.size <-c(group.size,length(environment(res.ecdf[[i]])$x)) 
    }
    
       
    layout <-  matrix(group.size,nrow=nbgroup,ncol=nbvar)
    sum2groups <- apply(layout,2,sum,na.rm=TRUE)
    byvar <- factor(rep(var.list,sum2groups),levels=c(var.list),ordered=FALSE)
    bygroup <- factor(rep(rep(group.list,nbvar),times=group.size[!is.na(group.size)]),levels=c(group.list),ordered=FALSE)
    
    xyplot(y.ecdf~x.ecdf|byvar,groups=bygroup,
           allow.mult = TRUE,
           par.settings=list(superpose.line=list(col=c(1:nbgroup))),
           panel="panel.superpose",
           panel.groups = "panel.linejoin",
           par.strip.text=list(cex=0.7),
           as.table=TRUE,
           key = list(lines=list(col=c(1:nbgroup)),
             cex=0.7,
             text =list(as.character(group.list)),
             columns = 4),
           col=c(1:nbgroup),
           xlab = xlab,
           ylab = ylab, ...)
    
}
