\name{boxplot.FCS}
\alias{boxplot.FCS}

\title{Create boxplots one parameter of one (or more) FCS object(s)}
\description{
  Produce box-and-whisker plot(s) of a single column variable specified from the
  data of one (or more) FCS object(s).
}
\usage{
boxplot.FCS(x, varpos=c(1),...)                      
}

\arguments{
  \item{x}{a list of  one (or more) FCS object(s) or a cytoSet object}

  \item{varpos}{the numerical column variable position of the data of
    the FCS object}

  \item{...}{any other arguments are passed to the \code{\link{boxplot}}
  function}
}  

\details{
  If several FCS objects are supplied parallel boxplots will be
  plotted.
  Other options from the functions \code{\link{plot}},
  \code{\link{boxplot}}.
}

\value{
  The \code{\link{boxplot}} will output a list with the following components:
  \item{stats} 	a matrix, each column contains the extreme of the lower whisker, the lower hinge, the median, the upper hinge and the extreme of the upper whisker for one group/plot.
  \item{n} 	a vector with the number of observations in each group.
  \item{conf} 	a matrix where each column contains the lower and upper extremes of the notch.
  \item{out} 	the values of any data points which lie beyond the extremes of the whiskers.
  \item{group} 	a vector of the same length as out whose elements indicate which group the outlier belongs to
  \item{names} 	a vector of names for the groups
}

\author{N. Le Meur}


\seealso{\code{\link{boxplot}},
  \code{\link{boxplot.stats}}}


\examples{
 ## Example I:
 require(rfcdmin)
 data(flowcyt.data)

 ## Draw a boxplot for the Foward SCatter parameter for the time points 1
 ## and 6 (in this experiment, each time point corresponds to a column of
 ## a 96 wells plates)
 mat <- matrix(c(1:2),1,2,byrow=TRUE)
 nf <- layout(mat,respect=TRUE)
 boxplot.FCS(flowcyt.data[1:8],varpos=c(1),col=c(1:8),main="FSC across stains time point 1",names=paste("stain",c(1:8),sep=""))
 boxplot.FCS(flowcyt.data[65:72],varpos=c(1),col=c(1:8),main="FSC across stains time point 9",names=paste("stain",c(1:8),sep=""))

 ##Example II:
 ## Read a serie of FCS files
 if (require(rfcdmin)) {

 ##obtaining the location of the fcs files in the data
  pathFiles<-system.file("bccrc", package="rfcdmin")
  drugFiles<-dir(pathFiles)

 ## reading in the FCS files
  drugData<-read.series.FCS(drugFiles,path=pathFiles,MY.DEBUG=FALSE)
  }

 ##Draw a boxplot for the Foward SCatter parameter
 ##for the differents aliquots (of the same cell line)
 ##tested with different compounds. 
 boxplot.FCS(drugData,varpos=c(1),col=c(1:8),main="FSC of differents aliquots from the same cell line treated with different compounds.")

 }

\keyword{aplot}
